Incorrect permissions and/or missing authentication were discovered on
FrontPage extensions used for publishing content.



A cyber-criminal might use this vulnerability to deface web sites and
potentially gain remote code execution on the server.